<h1 align="center">
<img src="https://github.com/pyfar/gallery/raw/main/docs/resources/logos/pyfar_logos_fixed_size_spharpy.png" width="300">
</h1><br>



[![PyPI version](https://badge.fury.io/py/spharpy.svg)](https://badge.fury.io/py/spharpy)
[![Documentation Status](https://readthedocs.org/projects/spharpy/badge/?version=latest)](https://spharpy.readthedocs.io/en/latest/?badge=latest)
[![CircleCI](https://circleci.com/gh/pyfar/spharpy.svg?style=shield)](https://circleci.com/gh/pyfar/spharpy)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/pyfar/gallery/main?labpath=docs/gallery/interactive/pyfar_introduction.ipynb)

Python package for spherical array processing.

Getting Started
===============

Check out the [example notebooks](https://github.com/pyfar/pyfar/blob/main/examples) - also available on [mybinder.org](https://mybinder.org/v2/gh/pyfar/spharpy/main?filepath=examples/) - for a tour of basic functionality and
[read the docs](https://spharpy.readthedocs.io/en/stable) for the complete documentation.

Installation
============

Use pip to install spharpy

    pip install spharpy

(Requires Python 3.11 or higher)

Audio file reading/writing is supported through [SoundFile](https://python-soundfile.readthedocs.io), which is based on
[libsndfile](http://www.mega-nerd.com/libsndfile/). On Windows and OS X, it will be installed automatically.
On Linux, you need to install libsndfile using your distribution’s package manager, for example ``sudo apt-get install libsndfile1``.
If the installation fails, please check out the [help section](https://pyfar-gallery.readthedocs.io/en/latest/help).

Contributing
============

Check out the [contributing guidelines](https://pyfar.readthedocs.io/en/stable/contributing.html) if you want to become part of pyfar.
